Linux workstation

Fedora 44 native package

libusb1-devel-doc

Development files for libusb1

Packages / Fedora 44 / Unspecified / libusb1-devel-doc

[Source: libusb1]

Package: libusb1-devel-doc (1.0.30-1.fc44)

[Project overview: libusb1]

External Resources:

Homepage: [libusb.info]

Similar packages:

Development files for libusb1

This package contains API documentation for libusb1.

Other Packages Related to libusb1-devel-doc:

  • dep: [libusb1-devel] (= 1.0.30-1.fc44)

    Development files for libusb1

Download libusb1-devel-doc

ArchitecturePackage SizeInstalled SizeFiles
noarch243 KiB1.9 MiB[list of files]

Caminhos de arquivo do pacote (69)

Paths come from the repository package-file index for the observed builds. They describe archive/package associations, not every file that will exist on a running system after maintainer scripts, alternatives, generated state, diversions, or installation choices.

  • /usr/share/doc/libusb1-devel-doc
  • /usr/share/doc/libusb1-devel-doc/api-1.0
  • /usr/share/doc/libusb1-devel-doc/api-1.0/annotated.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/classes.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/clipboard.js
  • /usr/share/doc/libusb1-devel-doc/api-1.0/deprecated.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/dir_6560186179ae86ab3fbed805e7cb86e4.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/doxygen_crawl.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/doxygen.css
  • /usr/share/doc/libusb1-devel-doc/api-1.0/doxygen.svg
  • /usr/share/doc/libusb1-devel-doc/api-1.0/dynsections.js
  • /usr/share/doc/libusb1-devel-doc/api-1.0/files.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/functions.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/functions_vars.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/group__libusb__asyncio.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/group__libusb__desc.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/group__libusb__dev.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/group__libusb__hotplug.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/group__libusb__lib.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/group__libusb__misc.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/group__libusb__poll.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/group__libusb__syncio.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/index.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/jquery.js
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb_8h_source.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb_api.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb_caveats.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb_contexts.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb_hotplug.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb_io.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb_mtasync.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb_packetoverflow.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/libusb.png
  • /usr/share/doc/libusb1-devel-doc/api-1.0/menudata.js
  • /usr/share/doc/libusb1-devel-doc/api-1.0/menu.js
  • /usr/share/doc/libusb1-devel-doc/api-1.0/navtree.css
  • /usr/share/doc/libusb1-devel-doc/api-1.0/pages.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__bos__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__bos__dev__capability__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__config__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__container__id__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__control__setup.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__device__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__endpoint__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__init__option.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__interface__association__descriptor__array.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__interface__association__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__interface__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__interface.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__iso__packet__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__platform__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__pollfd.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__ss__endpoint__companion__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__ssplus__sublink__attribute.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__ssplus__usb__device__capability__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__ss__usb__device__capability__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__transfer.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__usb__2__0__extension__descriptor.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/structlibusb__version.html
  • /usr/share/doc/libusb1-devel-doc/api-1.0/tabs.css
  • /usr/share/doc/libusb1-devel-doc/api-1.0/topics.html
  • /usr/share/doc/libusb1-devel-doc/dpfp.c
  • /usr/share/doc/libusb1-devel-doc/ezusb.c
  • /usr/share/doc/libusb1-devel-doc/fxload.c
  • /usr/share/doc/libusb1-devel-doc/hotplugtest.c
  • /usr/share/doc/libusb1-devel-doc/listdevs.c
  • /usr/share/doc/libusb1-devel-doc/sam3u_benchmark.c
  • /usr/share/doc/libusb1-devel-doc/testlibusb.c
  • /usr/share/doc/libusb1-devel-doc/xusb.c

Field source: Fedora 44 updates x86_64 revision 44-updates-x86_64:ffcac72d41afd8a62019714dd668a27f333f8ac19678580178b5b67c23ca6419

Usar este pacote

O OpenFactory pode iniciar este sistema operacional em uma máquina virtual do navegador, ou começar uma construção que inclui o nome nativo do pacote deste registro.

Versões, suites e repositórios

Cada linha é metadado do índice de pacotes para uma versão, arquitetura, suite e repositório. Nomes, URLs e tamanhos vêm da fonte; um link é um ponto de obtenção mutável, não uma redistribuição da OpenFactory.

VersionReleaseArchitectureRepositoryPackage sizeInstalled sizePublisher repository artifact
1.0.30-1.fc4444 / updatesnoarchFedora 44 · updates · x86_64243 KiB1.9 MiBPackages/l/libusb1-devel-doc-1.0.30-1.fc44.noarch.rpm
1.0.30-1.fc4444 / updatesnoarchFedora 44 · updates · aarch64243 KiB1.9 MiBPackages/l/libusb1-devel-doc-1.0.30-1.fc44.noarch.rpm
1.0.29-5.fc4444 / everythingnoarchFedora 44 · Everything · x86_64239 KiB1.8 MiBPackages/l/libusb1-devel-doc-1.0.29-5.fc44.noarch.rpm
1.0.29-5.fc4444 / everythingnoarchFedora 44 · Everything · aarch64239 KiB1.8 MiBPackages/l/libusb1-devel-doc-1.0.29-5.fc44.noarch.rpm

Field source: Fedora 44 updates x86_64 revision 44-updates-x86_64:ffcac72d41afd8a62019714dd668a27f333f8ac19678580178b5b67c23ca6419

Checksums e datas de observação

For an APT source, signature verification authenticates the repository metadata chain and the Packages index containing this source-reported artifact digest. It does not certify package safety.

1.0.30-1.fc44 / noarchObserved Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: f2f09273599a81f3e8c2de17d980ab50aebf31e20937c9433e16a23cba57942d

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' 'f2f09273599a81f3e8c2de17d980ab50aebf31e20937c9433e16a23cba57942d' 'libusb1-devel-doc-1.0.30-1.fc44.noarch.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 44 updates x86_64 revision 44-updates-x86_64:ffcac72d41afd8a62019714dd668a27f333f8ac19678580178b5b67c23ca6419

1.0.30-1.fc44 / noarchObserved Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: f2f09273599a81f3e8c2de17d980ab50aebf31e20937c9433e16a23cba57942d

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' 'f2f09273599a81f3e8c2de17d980ab50aebf31e20937c9433e16a23cba57942d' 'libusb1-devel-doc-1.0.30-1.fc44.noarch.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 44 updates aarch64 revision 44-updates-aarch64:6ecf7f9a3a707e537dd0c542e2f5fabb365c3c76c03b091b23e9c82d7f8ff88b

1.0.29-5.fc44 / noarchObserved Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: 595d30a9e5a68334f1bd94df146ff42041760fd28e7e4e149b413cfd6bef0900

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' '595d30a9e5a68334f1bd94df146ff42041760fd28e7e4e149b413cfd6bef0900' 'libusb1-devel-doc-1.0.29-5.fc44.noarch.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 44 Everything x86_64 revision 44-everything-x86_64:da3845427d188097f6fd71b417a039bdfb8efefc4f38ca44b5cbb94f95a18991

1.0.29-5.fc44 / noarchObserved Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: 595d30a9e5a68334f1bd94df146ff42041760fd28e7e4e149b413cfd6bef0900

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' '595d30a9e5a68334f1bd94df146ff42041760fd28e7e4e149b413cfd6bef0900' 'libusb1-devel-doc-1.0.29-5.fc44.noarch.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 44 Everything aarch64 revision 44-everything-aarch64:ad124f8125666e9059d7a8180427bdaea80f6286f71140457e5c7edd95883eee

Completude do registro

The completeness score measures metadata coverage, not software quality, security, compatibility, or suitability.

Summary and description
25/25
Artifact path and source digest
25/25
Dependency metadata
15/15
Package-file index
15/15
Homepage
5/5
License text
5/5
Source package or maintainer
10/10

Recorded total: 100/100

Field source: Fedora 44 Everything aarch64 revision 44-everything-aarch64:ad124f8125666e9059d7a8180427bdaea80f6286f71140457e5c7edd95883eee, Fedora 44 Everything x86_64 revision 44-everything-x86_64:da3845427d188097f6fd71b417a039bdfb8efefc4f38ca44b5cbb94f95a18991, Fedora 44 updates aarch64 revision 44-updates-aarch64:6ecf7f9a3a707e537dd0c542e2f5fabb365c3c76c03b091b23e9c82d7f8ff88b, Fedora 44 updates x86_64 revision 44-updates-x86_64:ffcac72d41afd8a62019714dd668a27f333f8ac19678580178b5b67c23ca6419. The cross-OS mapping is catalog-derived from the source-reported homepage; it does not establish authorship or publisher identity

Fontes e proveniência

Field-source links above resolve here. Each source entry names the metadata publisher, trust tier, exact snapshot revision, signature result, and observation time; catalog-derived mappings are labeled separately.

  • Authoritative source; repository metadata signature verified, revision 44-everything-aarch64:ad124f8125666e9059d7a8180427bdaea80f6286f71140457e5c7edd95883eee

    Signature verification covers the configured repository metadata chain. It does not certify that the package is safe or suitable.

    Repository-signature verification record
    Signed-object SHA-256
    236514c32119ab3c85b81fbb9e5e9d92b07aeba0d19d64c9b4fc9117a1863769
    Signer fingerprint
    Not recorded
    Keyring revision
    RPM-GPG-KEY-fedora-44-primary
    SHA-256 93642aec521a1e5e96dd715f7ae0ec0850ebc9de09a94ce03cae5263f26cc18a
    Tool and policy
    1
    openfactory-software-catalog-signature-v1
    Verification time
    Sep 1, 2026
    Signed Release → package-index hash linkage

    Path: Not recorded
    Expected SHA-256: Not recorded
    Observed SHA-256: Not recorded
    Result: match verified

  • Authoritative source; repository metadata signature verified, revision 44-everything-x86_64:da3845427d188097f6fd71b417a039bdfb8efefc4f38ca44b5cbb94f95a18991

    Signature verification covers the configured repository metadata chain. It does not certify that the package is safe or suitable.

    Repository-signature verification record
    Signed-object SHA-256
    1300b99ac5d04b5561ad901320c8bd59ed1553f4971c3ce2ca48c40242c66676
    Signer fingerprint
    Not recorded
    Keyring revision
    RPM-GPG-KEY-fedora-44-primary
    SHA-256 93642aec521a1e5e96dd715f7ae0ec0850ebc9de09a94ce03cae5263f26cc18a
    Tool and policy
    1
    openfactory-software-catalog-signature-v1
    Verification time
    Sep 1, 2026
    Signed Release → package-index hash linkage

    Path: Not recorded
    Expected SHA-256: Not recorded
    Observed SHA-256: Not recorded
    Result: match verified

  • Authoritative source; repository metadata signature verified, revision 44-updates-aarch64:6ecf7f9a3a707e537dd0c542e2f5fabb365c3c76c03b091b23e9c82d7f8ff88b

    Signature verification covers the configured repository metadata chain. It does not certify that the package is safe or suitable.

    Repository-signature verification record
    Signed-object SHA-256
    2ec0ba92e556309075d8efe3c3301b36bb7ecd47c4e17566f0192c9c5436ed5f
    Signer fingerprint
    Not recorded
    Keyring revision
    RPM-GPG-KEY-fedora-44-primary
    SHA-256 93642aec521a1e5e96dd715f7ae0ec0850ebc9de09a94ce03cae5263f26cc18a
    Tool and policy
    1
    openfactory-software-catalog-signature-v1
    Verification time
    Sep 1, 2026
    Signed Release → package-index hash linkage

    Path: Not recorded
    Expected SHA-256: Not recorded
    Observed SHA-256: Not recorded
    Result: match verified

  • Authoritative source; repository metadata signature verified, revision 44-updates-x86_64:ffcac72d41afd8a62019714dd668a27f333f8ac19678580178b5b67c23ca6419

    Signature verification covers the configured repository metadata chain. It does not certify that the package is safe or suitable.

    Repository-signature verification record
    Signed-object SHA-256
    a69a0ab020457a7af2515066b7caccb3950bcf9dc7bedb52b1850098d9857ae1
    Signer fingerprint
    Not recorded
    Keyring revision
    RPM-GPG-KEY-fedora-44-primary
    SHA-256 93642aec521a1e5e96dd715f7ae0ec0850ebc9de09a94ce03cae5263f26cc18a
    Tool and policy
    1
    openfactory-software-catalog-signature-v1
    Verification time
    Sep 1, 2026
    Signed Release → package-index hash linkage

    Path: Not recorded
    Expected SHA-256: Not recorded
    Observed SHA-256: Not recorded
    Result: match verified